summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/desktop.c2
-rw-r--r--src/ivi-compositor.h2
-rw-r--r--src/layout.c26
3 files changed, 15 insertions, 15 deletions
diff --git a/src/desktop.c b/src/desktop.c
index f3763de..efebfc1 100644
--- a/src/desktop.c
+++ b/src/desktop.c
@@ -134,7 +134,7 @@ desktop_surface_added(struct weston_desktop_surface *dsurface, void *userdata)
surface->ivi = ivi;
surface->dsurface = dsurface;
surface->role = IVI_SURFACE_ROLE_NONE;
- surface->activated_by_default = false;
+ surface->mapped = false;
surface->advertised_on_launch = false;
surface->checked_pending = false;
wl_list_init(&surface->link);
diff --git a/src/ivi-compositor.h b/src/ivi-compositor.h
index e89d215..424f126 100644
--- a/src/ivi-compositor.h
+++ b/src/ivi-compositor.h
@@ -264,7 +264,7 @@ struct ivi_surface {
int32_t x, y;
int32_t width, height;
} pending;
- bool activated_by_default;
+ bool mapped;
bool advertised_on_launch;
bool checked_pending;
diff --git a/src/layout.c b/src/layout.c
index 0356d01..a8f0956 100644
--- a/src/layout.c
+++ b/src/layout.c
@@ -284,7 +284,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
* we can't make use here of the ivi_layout_get_output_from_surface()
* due to the fact that we'll always land here when a surface performs
* a commit and pending_output will not bet set. This works in tandem
* with 'activated_by_default' at this point to avoid tripping over
* to a surface that continuously updates its content
*/
if (surf->role == IVI_SURFACE_ROLE_DESKTOP)
@@ -300,7 +300,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
return;
/* we can only activate it again by using the protocol */
- if (surf->activated_by_default)
+ if (surf->mapped)
return;
/* check first if there aren't any outputs being set */
@@ -340,7 +340,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
weston_desktop_surface_get_app_id(surf->dsurface),
ivi_layout_get_surface_role_name(surf));
ivi_layout_activate(r_output, app_id);
- surf->activated_by_default = true;
+ surf->mapped = true;
} else if (!app_id) {
/*
* applications not setting an app_id, or
@@ -352,7 +352,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
weston_log("Surface no app_id, role %s activating by default\n",
ivi_layout_get_surface_role_name(surf));
ivi_layout_activate_by_surf(r_output, surf);
- surf->activated_by_default = true;
+ surf->mapped = true;
}
}
@@ -369,7 +369,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
* ivi_layout_activate_complete() terminates so we use the
* current active surface to avoid hitting this again and again
* */
- if (surf->activated_by_default && output->active == surf)
+ if (surf->mapped && output->active == surf)
return;
if (app_id) {
@@ -377,7 +377,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
weston_desktop_surface_get_app_id(surf->dsurface),
ivi_layout_get_surface_role_name(surf));
ivi_layout_activate(output, app_id);
- surf->activated_by_default = true;
+ surf->mapped = true;
}
return;
}
@@ -409,7 +409,7 @@ ivi_layout_fullscreen_committed(struct ivi_surface *surface)
if (policy && policy->api.surface_activate_by_default &&
!policy->api.surface_activate_by_default(surface, surface->ivi) &&
- !surface->activated_by_default)
+ !surface->mapped)
return;
if (surface->view->is_mapped)
@@ -486,7 +486,7 @@ ivi_layout_split_committed(struct ivi_surface *surface)
if (policy && policy->api.surface_activate_by_default &&
!policy->api.surface_activate_by_default(surface, surface->ivi) &&
- !surface->activated_by_default)
+ !surface->mapped)
return;
if (surface->view->is_mapped)
@@ -584,7 +584,7 @@ ivi_layout_popup_committed(struct ivi_surface *surface)
if (policy && policy->api.surface_activate_by_default &&
!policy->api.surface_activate_by_default(surface, surface->ivi) &&
- !surface->activated_by_default)
+ !surface->mapped)
return;
if (surface->view->is_mapped)
@@ -639,8 +639,8 @@ ivi_layout_popup_re_add(struct ivi_surface *surface)
/* reset the activate by default in order to (still) allow the surface
* to be activaved using the request */
- if (!surface->activated_by_default)
- surface->activated_by_default = true;
+ if (!surface->mapped)
+ surface->mapped = true;
ivi_layout_popup_committed(surface);
}
@@ -658,8 +658,8 @@ ivi_layout_surface_is_split_or_fullscreen(struct ivi_surface *surf)
/* reset the activate by default in order to (still) allow the surface
* to be activaved using the request */
- if (!surf->activated_by_default)
- surf->activated_by_default = true;
+ if (!surf->mapped)
+ surf->mapped = true;
wl_list_for_each(is, &ivi->surfaces, link)
if (is == surf)
@@ -284,7 +284,7 @@ ivi_layout_desktop_committed(struct ivi_surface *surf)
* due to the fact that we'll always land here when a surface performs
* a commit and pending_output will not bet set. This works in tandem
- * with 'activated_by_default' at this point to avoid tripping over
+ * with 'mapped' at this point to avoid tripping over
* to a surface that continuously updates its content
*/